@@ -1,19 +1,19 @@
-//
-//   Copyright (C) 2003-2009 by Warren Woodford
-//   Heavily edited, with permision, by anticapitalista for antiX 2011-2014.
-//   Heavily revised by dolphin oracle, adrian, and anticaptialista 2018.
-//   Licensed under the Apache License, Version 2.0 (the "License");
-//   you may not use this file except in compliance with the License.
-//   You may obtain a copy of the License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the License is distributed on an "AS IS" BASIS,
-//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//   See the License for the specific language governing permissions and
-//   limitations under the License.
-//
+/****************************************************************************
+ *   Copyright (C) 2003-2009 by Warren Woodford
+ *   Heavily edited, with permision, by anticapitalista for antiX 2011-2014.
+ *   Heavily revised by dolphin oracle, adrian, and anticaptialista 2018.
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ ***************************************************************************/
 
 #include <cstdio>
 #include <unistd.h>
@@ -23,22 +23,21 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QDesktopWidget>
-#include <QDir>
 #include <QFile>
 #include <QFont>
 #include <QLibraryInfo>
 #include <QLocale>
 #include <QLoggingCategory>
 #include <QMessageBox>
-#include <QScopedPointer>
 #include <QString>
 #include <QStringList>
 #include <QTranslator>
+#include <QLockFile>
 
 #include "minstall.h"
 #include "version.h"
 
-static QScopedPointer<QFile> logFile;
+static QFile logFile("/var/log/minstall.log");
 
 void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg);
 
@@ -84,17 +83,19 @@ int main(int argc, char *argv[])
 
     a.setWindowIcon(QIcon("/usr/share/gazelle-installer-data/logo.png"));
 
-    // Set the logging files
-    const QString logFileName("/var/log/minstall.log");
-    logFile.reset(new QFile(logFileName));
-    // Open the file logging
-    if (logFile.data()->open(QFile::Append | QFile::Text)) {
-        // Set handler
-        qInstallMessageHandler(messageHandler);
-    } else {
-        qDebug() << "Cannot write to installer log:" << logFileName;
+    // The lock is released when this object is destroyed.
+    QLockFile lockfile("/var/lock/gazelle-installer.lock");
+    // Set Lock or exit if lockfile is present.
+    if (!lockfile.tryLock()) {
+        QMessageBox::critical(nullptr, QString(),
+            QApplication::tr("The installer won't launch because it appears to be running already in the background.\n\n"
+                "Please close it if possible, or run 'pkill minstall' in terminal."));
+        return EXIT_FAILURE;
     }
 
+    if (logFile.open(QFile::Append | QFile::Text)) qInstallMessageHandler(messageHandler);
+    else qDebug() << "Cannot write to installer log:" << logFile.fileName();
+
     QTranslator qtTran;
     if (qtTran.load(QLocale::system(), "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         a.installTranslator(&qtTran);
@@ -135,7 +136,7 @@ int main(int argc, char *argv[])
     MInstall minstall(parser, cfgfile);
     const QRect &geo = a.desktop()->availableGeometry(&minstall);
     if (parser.isSet("oobe")) minstall.setGeometry(geo);
-    else minstall.move((geo.width()-minstall.width())/2, (geo.height()-minstall.height())/2);
+    else minstall.move((geo.width() - minstall.width()) / 2, (geo.height() - minstall.height()) / 2);
     minstall.show();
     return a.exec();
 }
@@ -145,10 +146,10 @@ void messageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
 {
     // Write to terminal
     QTextStream term_out(stdout);
-    term_out << msg << endl;
+    term_out << msg << Qt::endl;
 
     // Open stream file writes
-    QTextStream out(logFile.data());
+    QTextStream out(&logFile);
 
     // Write the date of recording
     out << QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss.zzz ");
@@ -162,5 +163,5 @@ void messageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
     case QtFatalMsg:    out << "FTL "; break;
     }
     // Write to the output category of the message and the message itself
-    out << context.category << ": " << msg << endl;
+    out << context.category << ": " << msg << Qt::endl;
 }
