@@ -1,19 +1,26 @@
-// Basic partition manager for the installer.
-//
-//   Copyright (C) 2020 by AK-47
-//   Licensed under the Apache License, Version 2.0 (the "License");
-//   you may not use this file except in compliance with the License.
-//   You may obtain a copy of the License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the License is distributed on an "AS IS" BASIS,
-//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//   See the License for the specific language governing permissions and
-//   limitations under the License.
-//
-// This file is part of the gazelle-installer.
+/***************************************************************************
+ * Basic partition manager for the installer.
+ ***************************************************************************
+ *
+ *   Copyright (C) 2020-2021 by AK-47
+ *   Transplanted code, marked with comments further down this file:
+ *    - Copyright (C) 2003-2010 by Warren Woodford
+ *    - Heavily edited, with permision, by anticapitalista for antiX 2011-2014.
+ *    - Heavily revised by dolphin oracle, adrian, and anticaptialista 2018.
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ * This file is part of the gazelle-installer.
+ ***************************************************************************/
 
 #ifndef PARTMAN_H
 #define PARTMAN_H
@@ -38,7 +45,9 @@ class PartMan : public QObject
         UseFor,
         Encrypt,
         Format, // Text: existing format (not QLineEdit text)
-        Options // Data: tree widget item flags (see below)
+        Options, // Data: tree widget item flags (see below)
+        Dump,
+        Pass
     };
     enum TwitFlag {
         Drive,
@@ -65,7 +74,7 @@ class PartMan : public QObject
     void resizeColumnsToFit();
     static QString translateUse(const QString &alias);
     static QString describeUse(const QString &use);
-    bool formatLinuxPartition(const QString &dev, const QString &format, bool chkBadBlocks, const QString &label);
+    bool formatLinuxPartition(const QString &devpath, const QString &format, bool chkBadBlocks, const QString &label);
     void setEncryptChecks(const QString &use,
         enum Qt::CheckState state, QTreeWidgetItem *exclude);
     bool calculatePartBD();
@@ -105,6 +114,9 @@ class PartMan : public QObject
     QTreeWidgetItem *addSubvolumeItem(QTreeWidgetItem *twit);
     void scanSubvolumes(QTreeWidgetItem *partit);
     bool eventFilter(QObject *object, QEvent *event);
+    bool luksFormat(const QString &dev, const QByteArray &password);
+    bool luksOpen(const QString &dev, const QString &luksfs,
+        const QByteArray &password, const QString &options = QString());
 public:
     bool gptoverride=false, uefi=false, brave=false;
     long long rootSpaceNeeded = 0;
@@ -115,10 +127,8 @@ public:
     bool manageConfig(MSettings &config, bool save);
     QWidget *composeValidate(bool automatic, const QString &project);
     bool checkTargetDrivesOK();
-    bool luksMake(const QString &dev, const QByteArray &password);
-    bool luksOpen(const QString &dev, const QString &luksfs,
-        const QByteArray &password, const QString &options = QString());
     QTreeWidgetItem *selectedDriveAuto();
+    void clearAllUses();
     int layoutDefault(QTreeWidgetItem *drvit,
         int rootPercent, bool crypto, bool updateTree=true);
     int countPrepSteps();
